#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const common_tags_1 = require("common-tags");
const dotenv = tslib_1.__importStar(require("dotenv"));
const path = tslib_1.__importStar(require("path"));
const util_1 = require("util");
const cli_1 = require("../lib/cli");
const ExitSystem = tslib_1.__importStar(require("../lib/exit-system"));
const nexus_logger_1 = require("../lib/nexus-logger");
const process_1 = require("../lib/process");
const Commands = tslib_1.__importStar(require("./commands"));
const log = nexus_logger_1.rootLogger;
// use envar to boost perf, skip costly detection work
if (!process.env.GLOBAL_LOCAL_HANDOFF) {
    const depName = 'nexus';
    log.trace('execLayout start');
    const execLayout = process_1.detectExecLayout({ depName });
    log.trace('execLayout done', { execLayout });
    if (execLayout.toolProject && !execLayout.runningLocalTool) {
        if (execLayout.toolCurrentlyPresentInNodeModules) {
            process_1.globalLocalHandoff({
                localPackageDir: path.join(execLayout.project.nodeModulesDir, depName),
                globalPackageFilename: __filename,
            });
        }
        else {
            //todo detect package manager
            // const packageManager = await createPackageManager(undefined, { projectRoot })
            log.fatal(common_tags_1.stripIndent `
        You ran a global version of the Nexus CLI against your Nexus project. But your local project does not currently present within your node_modules.

        Please install your dependencies and then try your command again.

        Location of your global CLI (you invoked this): ${execLayout.thisProcessToolBin.realPath}
        Location of your local CLI will be here: ${execLayout.project.toolBinPath}
        `);
            process.exit(1);
        }
    }
}
dotenv.config();
ExitSystem.install();
process.on('uncaughtException', (e) => {
    console.error(e);
    ExitSystem.exit(1);
});
process.on('unhandledRejection', (e) => {
    console.error(e);
    ExitSystem.exit(1);
});
const cli = new cli_1.CLI({
    dev: new Commands.Dev(),
    build: new Commands.Build(),
    report: new Commands.Report(),
    create: {
        app: new Commands.Create.App(),
        plugin: new Commands.Create.Plugin(),
        __default: 'app',
    },
    __default: new Commands.__Default(),
});
cli
    .parse(process.argv.slice(2))
    .then((result) => {
    if (result instanceof cli_1.HelpError) {
        console.error(result.message);
        return 1;
    }
    else if (util_1.isError(result)) {
        console.error(result);
        return 1;
    }
    else {
        if (result !== undefined) {
            console.log(result);
        }
        return 0;
    }
})
    .then((exitCode) => {
    ExitSystem.exit(exitCode);
});
//# sourceMappingURL=main.js.map