"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const common_tags_1 = require("common-tags");
const fs = tslib_1.__importStar(require("fs-jetpack"));
const fs_1 = require("../fs");
const tsc_1 = require("../tsc");
const extractor_1 = require("./extractor");
const nexus_logger_1 = require("../nexus-logger");
const log = nexus_logger_1.rootLogger.child('add-to-context-extractor');
exports.NEXUS_DEFAULT_RUNTIME_CONTEXT_TYPEGEN_PATH = fs.path('node_modules', '@types', 'typegen-nexus-context', 'index.d.ts');
/**
 * Run the pure extractor and then write results to a typegen module.
 */
async function generateContextExtractionArtifacts(layout) {
    log.trace('starting context type extraction');
    const program = tsc_1.createTSProgram(layout, { withCache: true });
    const contextTypes = extractor_1.extractContextTypes(program.getProgram());
    await writeContextTypeGenFile(contextTypes);
    log.trace('finished context type extraction', { contextTypes });
    return contextTypes;
}
exports.generateContextExtractionArtifacts = generateContextExtractionArtifacts;
/**
 * Output the context types to a typegen file.
 */
async function writeContextTypeGenFile(contextTypes) {
    const addToContextInterfaces = contextTypes.types
        .map((result) => `interface Context ${result}`)
        .join('\n\n');
    const content = common_tags_1.codeBlock `
    import app from 'nexus'

    // Imports for types referenced by context types.

    ${contextTypes.typeImports
        .map((ti) => renderImport({ names: [ti.name], from: ti.modulePath }))
        .join('\n')}

    // Tap into Nexus' global context interface. Make all local context interfaces merge into it.

    declare global {
      export interface NexusContext extends Context {}
    }

    // The context types extracted from the app.

    ${addToContextInterfaces.length > 0 ? addToContextInterfaces : `interface Context {}`}
  `;
    await fs_1.hardWriteFile(exports.NEXUS_DEFAULT_RUNTIME_CONTEXT_TYPEGEN_PATH, content);
}
exports.writeContextTypeGenFile = writeContextTypeGenFile;
function renderImport(input) {
    return `import { ${input.names.join(', ')} } from '${input.from}'`;
}
//# sourceMappingURL=typegen.js.map