"use strict";
// Borrowed from `graphql-request`
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const node_fetch_1 = tslib_1.__importDefault(require("node-fetch"));
const types_1 = require("./types");
var types_2 = require("./types");
exports.ClientError = types_2.ClientError;
class GraphQLClient {
    constructor(url, options) {
        this.url = url;
        this.options = options || {};
    }
    async rawRequest(query, variables) {
        const _a = this.options, { headers } = _a, others = tslib_1.__rest(_a, ["headers"]);
        const body = JSON.stringify({
            query,
            variables: variables ? variables : undefined,
        });
        const response = await node_fetch_1.default(this.url, Object.assign({ method: 'POST', headers: Object.assign({ 'Content-Type': 'application/json' }, headers), body }, others));
        const result = await getResult(response);
        if (response.ok && !result.errors && result.data) {
            const { headers, status } = response;
            return Object.assign(Object.assign({}, result), { headers, status });
        }
        else {
            const errorResult = typeof result === 'string' ? { error: result } : result;
            throw new types_1.ClientError(Object.assign(Object.assign({}, errorResult), { status: response.status, headers: response.headers }), { query, variables });
        }
    }
    async request(query, variables) {
        const _a = this.options, { headers } = _a, others = tslib_1.__rest(_a, ["headers"]);
        const body = JSON.stringify({
            query,
            variables: variables ? variables : undefined,
        });
        const response = await node_fetch_1.default(this.url, Object.assign({ method: 'POST', headers: Object.assign({ 'Content-Type': 'application/json' }, headers), body }, others));
        const result = await getResult(response);
        if (response.ok && !result.errors && result.data) {
            return result.data;
        }
        else {
            const errorResult = typeof result === 'string' ? { error: result } : result;
            throw new types_1.ClientError(Object.assign(Object.assign({}, errorResult), { status: response.status }), { query, variables });
        }
    }
    setHeaders(headers) {
        this.options.headers = headers;
        return this;
    }
    setHeader(key, value) {
        const { headers } = this.options;
        if (headers) {
            headers[key] = value;
        }
        else {
            this.options.headers = { [key]: value };
        }
        return this;
    }
}
exports.GraphQLClient = GraphQLClient;
async function rawRequest(url, query, variables) {
    const client = new GraphQLClient(url);
    return client.rawRequest(query, variables);
}
exports.rawRequest = rawRequest;
async function request(url, query, variables) {
    const client = new GraphQLClient(url);
    return client.request(query, variables);
}
exports.request = request;
exports.default = request;
async function getResult(response) {
    const contentType = response.headers.get('Content-Type');
    if (contentType && contentType.startsWith('application/json')) {
        return response.json();
    }
    else {
        return response.text();
    }
}
//# sourceMappingURL=index.js.map