"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const nexus_logger_1 = require("../nexus-logger");
const utils_1 = require("../utils");
const import_1 = require("./import");
const lens_1 = require("./lens");
const utils_2 = require("./utils");
const log = nexus_logger_1.rootLogger.child('plugin');
/**
 * Fully import and load the runtime plugins, if any, amongst the given plugins.
 */
function importAndLoadRuntimePlugins(plugins) {
    return filterValidPlugins(plugins)
        .map(utils_2.entrypointToManifest)
        .filter((m) => m.runtime)
        .map((m) => {
        return {
            run: import_1.importPluginDimension('runtime', m),
            manifest: m,
        };
    })
        .map((plugin) => {
        log.trace('loading runtime plugin', { name: plugin.manifest.name });
        return plugin.run(lens_1.createRuntimeLens(plugin.manifest.name));
    });
}
exports.importAndLoadRuntimePlugins = importAndLoadRuntimePlugins;
/**
 * Fully import and load the worktime plugins, if any, amongst the given plugins.
 */
function importAndLoadWorktimePlugins(plugins, layout) {
    return filterValidPlugins(plugins)
        .map(utils_2.entrypointToManifest)
        .filter((m) => m.worktime)
        .map((m) => {
        return {
            run: import_1.importPluginDimension('worktime', m),
            manifest: m,
        };
    })
        .map((plugin) => {
        log.trace('loading worktime plugin', { name: plugin.manifest.name });
        const lens = lens_1.createWorktimeLens(layout, plugin.manifest.name);
        plugin.run(lens);
        return {
            name: plugin.manifest.name,
            // plugin will have hooked onto hooks via mutation now, and framework
            // will call those hooks
            hooks: lens.hooks,
        };
    });
}
exports.importAndLoadWorktimePlugins = importAndLoadWorktimePlugins;
/**
 * Fully import and load the testtime plugins, if any, amongst the given plugins.
 */
function importAndLoadTesttimePlugins(plugins) {
    return filterValidPlugins(plugins)
        .map(utils_2.entrypointToManifest)
        .filter((m) => m.testtime)
        .map((m) => {
        return {
            run: import_1.importPluginDimension('testtime', m),
            manifest: m,
        };
    })
        .map((plugin) => {
        log.trace('loading testtime plugin', { name: plugin.manifest.name });
        return plugin.run(lens_1.createBaseLens(plugin.manifest.name));
    });
}
exports.importAndLoadTesttimePlugins = importAndLoadTesttimePlugins;
/**
 * Return only valid plugins. Invalid plugins will be logged as a warning.
 */
function filterValidPlugins(plugins) {
    const [validPlugins, invalidPlugins] = utils_1.partition(plugins, isValidPlugin);
    if (invalidPlugins.length > 0) {
        log.warn(`Some invalid plugins were passed to Nexus. They are being ignored.`, {
            invalidPlugins,
        });
    }
    return validPlugins;
}
exports.filterValidPlugins = filterValidPlugins;
/**
 * Predicate function, is the given plugin a valid one.
 */
function isValidPlugin(plugin) {
    const hasPackageJsonPath = 'packageJsonPath' in plugin;
    return hasPackageJsonPath;
}
exports.isValidPlugin = isValidPlugin;
//# sourceMappingURL=load.js.map