"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const common_tags_1 = require("common-tags");
const nexus_logger_1 = require("../nexus-logger");
const process_1 = require("../process");
const Reflection = tslib_1.__importStar(require("../reflection/reflect"));
const log = nexus_logger_1.rootLogger.child('plugin');
/**
 * Normalize a raw plugin manifest.
 *
 * @remarks
 *
 * The raw plugin manifest is what the plugin author defined. This supplies
 * defaults and fulfills properties to produce standardized manifest data.
 */
function entrypointToManifest(plugin) {
    var _a;
    try {
        const packageJson = require(plugin.packageJsonPath);
        if (!packageJson.name) {
            process_1.fatal(`One of your plugin has a missing required \`name\` property in its package.json`, {
                packageJsonPath: plugin.packageJsonPath,
                packageJson,
            });
        }
        return Object.assign(Object.assign({}, plugin), { name: packageJson.name, packageJson });
    }
    catch (error) {
        process_1.fatal(common_tags_1.stripIndent `
       An error occured when reading the package.json of one of your Nexus plugin:

       ${(_a = error.stack) !== null && _a !== void 0 ? _a : error}
    `, { plugin });
    }
}
exports.entrypointToManifest = entrypointToManifest;
/**
 * This gets all the plugins in use in the app.
 *
 * @remarks
 *
 * This is useful for the CLI to get worktime plugins. This will run the app in
 * data mode, in this process.
 */
async function getUsedPlugins(layout) {
    try {
        const reflection = await Reflection.reflect(layout, { usedPlugins: true });
        if (!reflection.success) {
            throw reflection.error;
        }
        log.trace('got used plugins', { validPlugins: reflection.plugins });
        return reflection.plugins;
    }
    catch (e) {
        process_1.fatal('Failed to scan app for used plugins because there is a runtime error in the app', {
            error: e,
        });
    }
}
exports.getUsedPlugins = getUsedPlugins;
//# sourceMappingURL=utils.js.map