/// <reference types="node" />
import { SpawnSyncOptions } from 'child_process';
/**
 * Log a meaningful semantic error message sans stack track and then crash
 * the program with exit code 1. Parameters are a passthrough to `console.error`.
 */
export declare function fatal(template: string, context?: Record<string, unknown>): never;
export declare type SuccessfulRunResult = {
    command: string;
    stderr: null | string;
    stdout: null | string;
    signal: null | string;
    exitCode: null | number;
    error: null | Error;
};
export declare type RunOptions = Omit<SpawnSyncOptions, 'encoding'> & {
    envAdditions?: Record<string, string | undefined>;
    require?: boolean;
};
export declare function runSync(commandRaw: string, options?: RunOptions): SuccessfulRunResult;
export declare function run(commandRaw: string, options?: RunOptions): Promise<SuccessfulRunResult>;
export declare const createRunner: (cwd: string) => typeof runSync;
export declare function clearConsole(): void;
/**
 * Handoff execution from a global to local version of a package.
 *
 * If the givne global module path is not a real node package (defined as being
 * unable to locate its package.json file) then an error will be thrown.
 *
 * An environment variable called `GLOBAL_LOCAL_HANDOFF` will be set to
 * `"true"`. Use this to short-circuit startup logic.
 */
export declare function globalLocalHandoff(input: {
    localPackageDir: string;
    globalPackageFilename: string;
}): void;
export * from './detect-exec-layout';
//# sourceMappingURL=index.d.ts.map