"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const child_process_1 = require("child_process");
const Path = tslib_1.__importStar(require("path"));
const nexus_logger_1 = require("../nexus-logger");
const serialize_error_1 = require("serialize-error");
const stage_1 = require("./stage");
const log = nexus_logger_1.rootLogger.child('reflection');
function reflect(layout, opts) {
    log.trace('reflection started');
    return new Promise((resolve) => {
        var _a;
        const cp = child_process_1.fork(Path.join(__dirname, 'fork-script.js'), [], {
            cwd: layout.projectRoot,
            stdio: 'pipe',
            env: Object.assign(Object.assign(Object.assign({}, process.env), { NEXUS_REFLECTION_LAYOUT: JSON.stringify(layout.data) }), stage_1.saveReflectionStageEnv(opts.usedPlugins ? 'plugin' : 'typegen')),
        });
        cp.on('message', (message) => {
            if (message.type === 'success-plugin' && opts.usedPlugins) {
                resolve({ success: true, plugins: message.data.plugins });
            }
            if (message.type === 'success-typegen' && opts.artifacts) {
                resolve({ success: true });
            }
            if (message.type === 'error') {
                resolve({ success: false, error: serialize_error_1.deserializeError(message.data.serializedError) });
            }
        });
        cp.on('error', (err) => {
            log.trace('error', { err });
            resolve({ success: false, error: err });
        });
        (_a = cp.stderr) === null || _a === void 0 ? void 0 : _a.on('data', (err) => {
            log.trace('error', { err });
            resolve({ success: false, error: new Error(err) });
        });
        cp.on('exit', (code) => {
            if (code !== 0) {
                log.trace('failed with exit code !== 0', { code });
                resolve({
                    success: false,
                    error: new Error(`
        Runner failed with exit code "${code}".
      `),
                });
            }
        });
    });
}
exports.reflect = reflect;
//# sourceMappingURL=reflect.js.map