"use strict";
/**
 * This module is for reporting issues about Nexus. It extracts diagnostics
 * about the proejct and environment and can format them for a GitHub issue.
 */
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const os_1 = tslib_1.__importDefault(require("os"));
const Plugin = tslib_1.__importStar(require("../lib/plugin"));
/**
 * Extract diagnostics about the Nexus project.
 */
async function getNexusReport(layout) {
    var _a, _b, _c, _d;
    const pj = (_a = layout.packageJson) === null || _a === void 0 ? void 0 : _a.content;
    const deps = (_b = pj === null || pj === void 0 ? void 0 : pj.dependencies) !== null && _b !== void 0 ? _b : {};
    const otherDeps = Object.fromEntries(Object.entries(deps).filter((ent) => {
        return ent[0] !== 'nexus' && !ent[0].startsWith('nexus-plugin');
    }));
    const pluginEntrypoints = await Plugin.getUsedPlugins(layout);
    const pluginManifests = pluginEntrypoints.map(Plugin.entrypointToManifest);
    return {
        node: process.version,
        nexus: (_c = deps.nexus) !== null && _c !== void 0 ? _c : 'undefined',
        plugins: pluginManifests.map((m) => m.name),
        os: {
            platform: os_1.default.platform(),
            release: os_1.default.release(),
        },
        otherDependencies: otherDeps,
        devDependencies: (_d = pj === null || pj === void 0 ? void 0 : pj.devDependencies) !== null && _d !== void 0 ? _d : {},
        hasAppModule: layout.data.app.exists,
        packageManager: layout.packageManagerType,
    };
}
exports.getNexusReport = getNexusReport;
//# sourceMappingURL=report.js.map