/// <reference types="node" />
import * as Logger from '@nexus/logger';
import * as NexusSchema from '@nexus/schema';
import { CreateFieldResolverInfo } from '@nexus/schema/dist/core';
import { GraphQLFieldResolver, GraphQLResolveInfo } from 'graphql';
import * as HTTP from 'http';
import { NexusSchemaStatefulBuilders } from '../../lib/nexus-schema-stateful';
import { RuntimeContributions } from '../../lib/plugin';
import { MaybePromise } from '../../lib/utils';
import { AppState } from '../app';
import { SchemaSettingsManager } from './settings';
export declare type LazyState = {
    contextContributors: ContextContributor[];
    plugins: NexusSchema.core.NexusPlugin[];
    /**
     * GraphQL schema built by @nexus/schema
     *
     * @remarks
     *
     * Only available after assembly
     */
    schema: null | NexusSchema.core.NexusGraphQLSchema;
    /**
     * @remarks
     *
     * Only available after assembly
     */
    missingTypes: null | Record<string, NexusSchema.core.MissingType>;
};
export interface Request extends HTTP.IncomingMessage {
    log: Logger.Logger;
}
export declare type ContextContributor = (req: Request) => MaybePromise<Record<string, unknown>>;
declare type MiddlewareFn = (source: any, args: any, context: NexusSchema.core.GetGen<'context'>, info: GraphQLResolveInfo, next: GraphQLFieldResolver<any, any>) => any;
export interface Schema extends NexusSchemaStatefulBuilders {
    /**
     * todo link to website docs
     */
    use(schemaPlugin: NexusSchema.core.NexusPlugin): void;
    /**
     * todo link to website docs
     */
    middleware(fn: (config: CreateFieldResolverInfo) => MiddlewareFn | undefined): void;
    /**
     * todo link to website docs
     */
    addToContext(contextContributor: ContextContributor): void;
}
export interface SchemaInternal {
    private: {
        settings: SchemaSettingsManager;
        checks(): void;
        assemble(plugins: RuntimeContributions[]): void;
    };
    public: Schema;
}
export declare function create(appState: AppState): SchemaInternal;
export {};
//# sourceMappingURL=schema.d.ts.map