"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const NexusSchema = tslib_1.__importStar(require("@nexus/schema"));
const core_1 = require("@nexus/schema/dist/core");
const common_tags_1 = require("common-tags");
const Layout = tslib_1.__importStar(require("../../lib/layout"));
const nexus_schema_stateful_1 = require("../../lib/nexus-schema-stateful");
const logger_1 = require("./logger");
const settings_1 = require("./settings");
function createLazyState() {
    return {
        contextContributors: [],
        plugins: [],
        schema: null,
        missingTypes: null,
    };
}
function create(appState) {
    appState.schemaComponent = createLazyState();
    const statefulNexusSchema = nexus_schema_stateful_1.createNexusSchemaStateful();
    const settings = settings_1.createSchemaSettingsManager();
    const middleware = (fn) => {
        api.public.use(NexusSchema.plugin({
            // TODO: Do we need to expose the name property?
            name: 'local-middleware',
            onCreateFieldResolver(config) {
                return fn(config);
            },
        }));
    };
    const api = {
        public: Object.assign(Object.assign({}, statefulNexusSchema.builders), { use(plugin) {
                if (appState.assembled === true) {
                    logger_1.log.warn(common_tags_1.stripIndent `
            A Nexus Schema plugin was ignored because it was loaded after the server was started
            Make sure to call \`schema.use\` before you call \`server.start\`
          `);
                }
                appState.schemaComponent.plugins.push(plugin);
            },
            addToContext(contextContributor) {
                appState.schemaComponent.contextContributors.push(contextContributor);
            },
            middleware }),
        private: {
            settings: settings,
            checks() {
                NexusSchema.core.assertNoMissingTypes(appState.schemaComponent.schema, appState.schemaComponent.missingTypes);
                if (statefulNexusSchema.state.types.length === 0) {
                    logger_1.log.warn(Layout.schema.emptyExceptionMessage());
                }
            },
            assemble: (plugins) => {
                const nexusSchemaConfig = settings_1.mapSettingsToNexusSchemaConfig(plugins, settings.data);
                nexusSchemaConfig.types.push(...statefulNexusSchema.state.types);
                nexusSchemaConfig.plugins.push(...appState.schemaComponent.plugins);
                const { schema, missingTypes } = core_1.makeSchemaInternal(nexusSchemaConfig);
                appState.schemaComponent.schema = schema;
                appState.schemaComponent.missingTypes = missingTypes;
            },
        },
    };
    return api;
}
exports.create = create;
//# sourceMappingURL=schema.js.map