import * as NexusSchema from '@nexus/schema';
import * as Plugin from '../../lib/plugin';
import { Param1 } from '../../lib/utils';
declare type NexusSchemaConfig = NexusSchema.core.SchemaConfig;
export declare type SettingsInput = {
    /**
     *  See the [Nullability Guide](https://www.nexusjs.org/#/guides/schema?id=nullability-in-principal) for more details.
     */
    nullable?: {
        /**
         * Should passing arguments be optional for clients by default?
         *
         * @default true
         */
        inputs?: boolean;
        /**
         * Should the data requested by clients _not_ be guaranteed to be returned by default?
         *
         * @default true
         */
        outputs?: boolean;
    };
    /**
     * todo
     */
    connections?: {
        /**
         * todo
         */
        default?: ConnectionConfig | false;
        [typeName: string]: ConnectionConfig | undefined | false;
    };
    /**
     * Should a [GraphQL SDL file](https://www.prisma.io/blog/graphql-sdl-schema-definition-language-6755bcb9ce51) be generated when the app is built and to where?
     *
     * A relative path is interpreted as being relative to the project directory.
     * Intermediary folders are created automatically if they do not exist
     * already.
     *
     * @default false
     */
    generateGraphQLSDLFile?: false | string;
    /**
     * A glob pattern which will be used to find the files from which to extract the backing types used in the `rootTyping` option of `schema.(objectType|interfaceType|unionType|enumType)`
     *
     * @default "./**\/*.ts"
     *
     * @example "./**\/*.backing.ts"
     */
    rootTypingsGlobPattern?: string;
};
export declare type SettingsData = SettingsInput;
export declare function changeSettings(state: SettingsData, newSettings: SettingsInput): void;
export declare function mapSettingsToNexusSchemaConfig(frameworkPlugins: Plugin.RuntimeContributions[], settings: SettingsData): NexusSchemaConfig;
declare type ConnectionPluginConfig = NonNullable<Param1<typeof NexusSchema.connectionPlugin>>;
export declare type ConnectionConfig = Omit<ConnectionPluginConfig, 'nexusFieldName'>;
export declare function createSchemaSettingsManager(): {
    change: (newSettings: SettingsInput) => void;
    data: SettingsInput;
};
export declare type SchemaSettingsManager = ReturnType<typeof createSchemaSettingsManager>;
export {};
//# sourceMappingURL=settings.d.ts.map