"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const NexusSchema = tslib_1.__importStar(require("@nexus/schema"));
const Lo = tslib_1.__importStar(require("lodash"));
const logger_1 = require("./logger");
const log = logger_1.log.child('settings');
function changeSettings(state, newSettings) {
    var _a, _b;
    if (newSettings.nullable) {
        if (state.nullable === undefined) {
            state.nullable = {};
        }
        Lo.merge(state.nullable, newSettings.nullable);
    }
    if (newSettings.generateGraphQLSDLFile) {
        state.generateGraphQLSDLFile = newSettings.generateGraphQLSDLFile;
    }
    if (newSettings.rootTypingsGlobPattern) {
        state.rootTypingsGlobPattern = newSettings.rootTypingsGlobPattern;
    }
    if (newSettings.connections) {
        state.connections = (_a = state.connections) !== null && _a !== void 0 ? _a : {};
        const _c = newSettings.connections, { types } = _c, connectionPluginConfig = tslib_1.__rest(_c, ["types"]);
        if (types) {
            state.connections.types = (_b = state.connections.types) !== null && _b !== void 0 ? _b : {};
            Object.assign(state.connections.types, types);
        }
        Object.assign(state.connections, connectionPluginConfig);
    }
}
exports.changeSettings = changeSettings;
function mapSettingsToNexusSchemaConfig(frameworkPlugins, settings) {
    var _a, _b, _c, _d, _e, _f;
    const runtimeTypegenConfig = {
        // Always false here, then set to true in the reflection module
        outputs: false,
        shouldGenerateArtifacts: false,
        shouldExitAfterGenerateArtifacts: false,
    };
    const baseConfig = Object.assign({ nonNullDefaults: {
            input: !((_b = (_a = settings === null || settings === void 0 ? void 0 : settings.nullable) === null || _a === void 0 ? void 0 : _a.inputs) !== null && _b !== void 0 ? _b : true),
            output: !((_d = (_c = settings === null || settings === void 0 ? void 0 : settings.nullable) === null || _c === void 0 ? void 0 : _c.outputs) !== null && _d !== void 0 ? _d : true),
        }, typegenAutoConfig: {
            sources: [],
        }, types: [], plugins: [] }, runtimeTypegenConfig);
    baseConfig.plugins.push(...processConnectionsConfig(settings));
    // Merge the plugin nexus plugins
    for (const frameworkPlugin of frameworkPlugins) {
        const schemaPlugins = (_f = (_e = frameworkPlugin.schema) === null || _e === void 0 ? void 0 : _e.plugins) !== null && _f !== void 0 ? _f : [];
        baseConfig.plugins.push(...schemaPlugins);
    }
    log.trace('config built', { config: baseConfig });
    return baseConfig;
}
exports.mapSettingsToNexusSchemaConfig = mapSettingsToNexusSchemaConfig;
/**
 * Process the schema connection settings into nexus schema relay connection
 * plugins.
 */
function processConnectionsConfig(settings) {
    if (settings.connections === undefined) {
        return [
            defaultConnectionPlugin({
                nexusSchemaImportId: 'nexus/components/schema',
            }),
        ];
    }
    const instances = [];
    const _a = settings.connections, { default: defaultTypeConfig } = _a, customTypesConfig = tslib_1.__rest(_a, ["default"]);
    for (const [name, config] of Object.entries(customTypesConfig)) {
        if (config) {
            instances.push(NexusSchema.connectionPlugin(Object.assign({ nexusSchemaImportId: 'nexus/components/schema', nexusFieldName: name }, config)));
        }
    }
    if (defaultTypeConfig) {
        instances.push(defaultConnectionPlugin(defaultTypeConfig));
    }
    return instances;
}
function defaultConnectionPlugin(configBase) {
    return NexusSchema.connectionPlugin(Object.assign(Object.assign({}, configBase), { nexusFieldName: 'connection' }));
}
function defaultSettings() {
    return {};
}
function createSchemaSettingsManager() {
    const data = defaultSettings();
    const change = (newSettings) => {
        return changeSettings(data, newSettings);
    };
    return {
        change,
        data,
    };
}
exports.createSchemaSettingsManager = createSchemaSettingsManager;
//# sourceMappingURL=settings.js.map