/// <reference types="node" />
import * as Logger from '@nexus/logger';
import { Express } from 'express';
import * as ExpressGraphQL from 'express-graphql';
import * as GraphQL from 'graphql';
import * as HTTP from 'http';
import * as Plugin from '../../lib/plugin';
import * as Utils from '../../lib/utils';
import * as ServerSettings from './settings';
declare type Request = HTTP.IncomingMessage & {
    log: Logger.Logger;
};
declare type ContextContributor<T extends {}> = (req: Request) => Utils.MaybePromise<T>;
export declare type ExpressInstance = Omit<Express, 'listen'>;
export interface BaseServer {
    /**
     * Start the server instance
     */
    start(): Promise<void>;
    /**
     * Stop the server instance
     */
    stop(): Promise<void>;
}
/**
 * [API Reference](https://www.nexusjs.org/#/api/modules/main/exports/server)  ⌁  [Guide](todo)
 *
 * ### todo
 *
 */
export interface Server extends BaseServer {
    /**
     * Gives access to the underlying express instance
     * Do not use `express.listen` but `server.start` instead
     */
    express: ExpressInstance;
}
export declare type SetupExpressInput = ExpressGraphQL.OptionsData & ServerSettings.SettingsData & {
    context: ContextCreator;
};
interface ServerFactory {
    setupAndStart(opts: {
        schema: GraphQL.GraphQLSchema;
        plugins: Plugin.RuntimeContributions[];
        contextContributors: ContextContributor<any>[];
    }): Promise<void>;
    stop(): Promise<void>;
    express: ExpressInstance;
    settings: {
        change(settings: ServerSettings.SettingsInput): void;
        data: ServerSettings.SettingsData;
    };
}
export declare function create(): ServerFactory;
declare type AnonymousRequest = Record<string, any>;
declare type AnonymousContext = Record<string, any>;
declare type ContextCreator<Req extends AnonymousRequest = AnonymousRequest, Context extends AnonymousContext = AnonymousContext> = (req: Req) => Promise<Context>;
export {};
//# sourceMappingURL=server-old.d.ts.map