"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const lodash_1 = require("lodash");
/**
 * Create an app settings component.
 *
 * @remarks
 *
 * The app settings component centralizes settings management of all other
 * components. Therefore it depends on the other components. It requires their
 * settings managers.
 */
function create({ schemaSettings, serverSettings, log, }) {
    const settings = {
        change(newSettings) {
            if (newSettings.logger) {
                log.settings(newSettings.logger);
            }
            if (newSettings.schema) {
                schemaSettings.change(newSettings.schema);
            }
            if (newSettings.server) {
                serverSettings.change(newSettings.server);
            }
        },
        current: {
            logger: log.settings,
            schema: schemaSettings.data,
            server: serverSettings.data,
        },
        original: lodash_1.cloneDeep({
            logger: log.settings,
            schema: schemaSettings.data,
            server: serverSettings.data,
        }),
    };
    return {
        public: settings,
    };
}
exports.create = create;
//# sourceMappingURL=index.js.map