import { GraphQLClient } from '../lib/graphql-client';
declare type AppClient = {
    query: GraphQLClient['request'];
};
export declare function createAppClient(apiUrl: string): AppClient;
export interface TestContextAppCore {
    query: AppClient['query'];
    server: {
        start: () => Promise<void>;
        stop: () => Promise<void>;
    };
}
export interface TestContextCore {
    app: TestContextAppCore;
}
declare global {
    interface NexusTestContextApp extends TestContextAppCore {
    }
    interface NexusTestContextRoot {
        app: NexusTestContextApp;
    }
}
export declare type TestContext = NexusTestContextRoot;
/**
 * Setup a test context providing utilities to query against your GraphQL API
 *
 * @example
 *
 * With jest
 * ```
 * import { setupTest, TestContext } from 'nexus/testing'
 *
 * let testCtx: TestContext
 *
 * beforeAll(async () => {
 *  testCtx = await setupTest()
 *  await testCtx.server.start()
 * })
 *
 * afterAll(async () => {
 *  await testCtx.server.stop()
 * })
 * ```
 */
export declare function createTestContext(): Promise<TestContext>;
export {};
//# sourceMappingURL=testing.d.ts.map